@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2019-2020 -- leonerd@leonerd.org.uk
 
-package Object::Pad 0.45;
+package Object::Pad 0.46;
 
 use v5.14;
 use warnings;
@@ -723,15 +723,14 @@ sub import_into
    croak "Unrecognised import symbols @{[ keys %syms ]}" if keys %syms;
 }
 
-# Double-experimental MOP-like API
-# Currently entirely undocumented. May eventually become part of an Object::Pad::MOP API
 sub begin_class
 {
    my $class = shift;
    my ( $name, %args ) = @_;
 
-   # TODO: Do we accept an `isa` arg ?
-   Object::Pad::_begin_class( $name, $args{extends} );
+   Carp::carp "Object::Pad->begin_class is deprecated; use Object::Pad::MOP::Class->begin_class instead";
+
+   Object::Pad::MOP::Class->begin_class( $name, %args );
 }
 
 # The universal base-class methods
@@ -881,6 +880,10 @@ time working on this module and other perl features.
 
 Oetiker+Partner AG L<https://www.oetiker.ch/en/>
 
+=item *
+
+Deriv L<http://deriv.com>
+
 =back
 
 Additional details may be found at
